## **Journal of Sports Sciences**

**[ISSN: 0264-0414 (Print) 1466-447X (Online) Journal homepage: https://www.tandfonline.com/loi/rjsp20](https://www.tandfonline.com/loi/rjsp20)**

# **New curve sprint test for soccer players: Reliability** **and relationship with linear sprint**

**Alberto Fílter, Jesús Olivares, Alfredo Santalla, Fabio Y. Nakamura, Irineu**
**Loturco & Bernardo Requena**

**To cite this article:** Alberto Fílter, Jesús Olivares, Alfredo Santalla, Fabio Y. Nakamura, Irineu
Loturco & Bernardo Requena (2019): New curve sprint test for soccer players: Reliability and
[relationship with linear sprint, Journal of Sports Sciences, DOI: 10.1080/02640414.2019.1677391](https://www.tandfonline.com/action/showCitFormats?doi=10.1080/02640414.2019.1677391)

**To link to this article:** [https://doi.org/10.1080/02640414.2019.1677391](https://doi.org/10.1080/02640414.2019.1677391)

Published online: 13 Oct 2019.

[Submit your article to this journal](https://www.tandfonline.com/action/authorSubmission?journalCode=rjsp20&show=instructions)

[View related articles](https://www.tandfonline.com/doi/mlt/10.1080/02640414.2019.1677391)

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/02640414.2019.1677391&domain=pdf&date_stamp=2019-10-13)

Full Terms & Conditions of access and use can be found at
[https://www.tandfonline.com/action/journalInformation?journalCode=rjsp20](https://www.tandfonline.com/action/journalInformation?journalCode=rjsp20)

JOURNAL OF SPORTS SCIENCES

<https://doi.org/10.1080/02640414.2019.1677391>

### New curve sprint test for soccer players: Reliability and relationship with linear sprint

Alberto Fílter a,b, Jesús Olivares b,c, Alfredo Santalla a,b, Fabio Y. Nakamura b, Irineu Loturco d,e,f
and Bernardo Requena b

aFaculty of Sport, University of Pablo de Olavide (UPO), Seville, Spain; bResearch and Development Department, Football Science Institute (FSI),
Granada, Spain; \[c\] Mixed University Institute of Sport and Health (IMUDS), Granada, Spain; \[d\] NAR – Nucleus of High Performance in Sport, Sao Paulo,
Brazil; \[e\] University of South Wales, Pontypridd, Wales, UK; \[f\] Department of Human Movement Science, Federal University of Sao Paulo, Brazil

ABSTRACT
The speed performance is involved not only in linear sprints, but also in a wide spectrum of multidirectional movements, such as curve sprinting. Curved sprint can be defined as sprint with gradual and
continuous change of direction (COD). Although ~85% of the actions performed at maximum velocity in
a professional soccer league are curvilinear sprints, there is not any specific test to assess this ability. This
study aimed to analyse the reliability of a new curve sprint test, and compare its results with those
obtained by soccer players in linear sprint. Forty experienced soccer players performed 3 attempts of
curve sprint (using the penalty arc) to right and left side (17 m), and 3 linear sprints (17 m) in two different
days. The ICCs (inter-session reliability) were 0.93 for sprint curve right side (CSRS) and 0.89 for sprint
curve left side (CSLS), considered “acceptable”. The CVs (intra-session reliability) were 0.87% in CSRS and
1.15% in CSLS. The coefficient of determination (R \[2\] ) between linear and curve sprinting was ~35%. The
association between curve sides was “very large” (r = 0.878; p \< 0.01). In summary, we showed that “curve
sprint test” is highly reliable, and that curvilinear and linear sprints are different and independent actions.

ARTICLE HISTORY
Accepted 10 September 2019

KEYWORDS
Non-linear sprint
performance; assessment;
semi-professional soccer
player

Introduction

Soccer is characterised as an intermittent team-sport in which
high-intensity activities (e.g., maximum sprints) are regularly
intertwined with actions of low and moderate intensities (e.g.,
walking and jogging) (Burgess, Naughton, & Norton, 2006;
Haugen, Tonnessen, Hisdal, & Seiler, 2013; Rampini, Coutts,
Castagna, Sassi, & Impellizzeri, 2007). Importantly, the number
of high-intensity running efforts per game has progressively
increased across the years (Barnes, Archer, Hogg, Bush, &
Bradley, 2014), more specifically during decisive match situations
(Faude, Koch, & Meyer, 2012; Mohr, Krustrup, & Bangsbo, 2003).
This reveals the critical importance of speed-related capabilities
for soccer performance, especially because multiple and successive accelerations are frequently observed during official games
(Bloomfield, Polman, & O’Donoghue, 2007; Rampini et al., 2007).
In addition, it is known that professional players have better
performance in sprints during matches (10, 20, 30, and 40
metres) than their less specialised counterparts (Bradley, Di
Mascio, Peart, Olsen, & Sheldon, 2010), but the duration of
these sprints during matches range from 2 to 4 s with respective
distances lesser than 20 metres (Barnes et al., 2014).

In elite soccer, the acceleration capacity is involved not
solely in linear sprints, but also in a wide spectrum of complex
and multidirectional motor-tasks (e.g., nonlinear sprints).
Accordingly, the “nonlinear sprint performance” appears to be
able to differentiate between professional and young soccer
players (Cardoso de Araújo, Baumgart, Freiwald, & Hoppe,
2017). In this regard, it has been consistently shown that soccer
players execute hundreds of directional changes throughout

the game, with many of these actions being characterised by
their less aggressive cutting turns and smoother angles (an arc)
(e.g., ≤15°) (Bloomfield et al., 2007). Of note, approximately 85%
of the manoeuvres performed at maximum velocity in
a professional soccer league consist of curvilinear sprints (i.e.,
curve sprints), which may be defined as the upright running
portion of the sprint completed with the presence of some
degree of curvature (Caldbeck, 2019). Nonetheless, despite
their critical importance, curve sprints have been largely overlooked by coaches and sport scientists.

From a general perspective, curvilinear motion regularly
occur in soccer (Bloomfield et al., 2007; Caldbeck, 2019), regardless of playing position (except for goalkeepers), typically
within a radius ranging from 3.5 to 11 m (Brice, Smith, &
Dyson, 2008). For obvious reasons, curve sprint technique presents singular and unique kinetic and kinematic features
(Churchill, Trewartha, & Salo, 2018). For example, when compared to maximum linear sprints, the velocity achieved during
curvilinear trajectories is usually lower in sprinters, which significantly affects the neuromechanical demands and requirements during these actions (Churchill, Salo, & Trewartha, 2015;
Churchill et al., 2018). Furthermore, since acceleration and
speed increase with “trunk rotation” over curvilinear trajectories, meaningful biomechanical differences between curve
and linear sprint techniques may be expected (Churchill et al.,
2015; Churchill, Trewartha, Bezodis, & Salo, 2016; Churchill et al.,
2018). As such, maximum linear and nonlinear sprint performances possibly embody different physical and technical capabilities and, consequently, should be independently assessed
and trained.

CONTACT Alberto Fílter <albertofr_91@hotmail.com> Faculty of Sport, University of Pablo de Olavide (UPO), Seville, Spain

© 2019 Informa UK Limited, trading as Taylor & Francis Group

2 A. FÍLTER ET AL.

There are many validated change of direction (COD) assessments and their relationships with other measurements such as
linear sprint tests are well established and confirmed in soccer
(Brughelli, Cronin, Levin, & Chaouachi, 2008). Curvilinear displacements have also been assessed in soccer players (Smith, Dyson,
Hale, & Janaway, 2006; Smith, Dyson, & Hate, 1997), but only at
submaximal speeds (e.g., jogging). Measuring speed and acceleration during curved sprints would be interesting and critical to
understand the determinants of performance in these actions,
which are frequent and decisive in soccer matches. Therefore,
the objectives of this study were to (a) test the reliability of
a new curvilinear sprint test for soccer players, and (b) compare
curved sprints with linear sprints, considering their mechanical
demands, and using the penalty arc of a soccer field as the
“standard measure”. We hypothesised that best performances in
linear sprint tests would not be necessarily associated with best
performances in curvilinear sprints. Furthermore, we expected
that the new “curve sprint test” would meet the reliability criteria.

Methods

Participants

Forty experienced soccer players (age: 22 ± 3.32 years;
height: 177 ± 4.81 cm; mass: 73.2 ± 6.2 kg) from a semiprofessional Spanish League were recruited for this study.
All subjects had more than 15 years of soccer experience
and were semi-professional players in the Second B and
Third Division Spanish League. Inclusion criteria were: train
four times a week, not having medical contraindications
for the tests, and have availability to carry out them. The
methodology used was approved by the Football Science
Institute Ethics Committee and conformed to the policy
statement with respect to the Declaration of Helsinki. All
subjects were informed of the risks and benefits of the
procedure and signed an informed consent for participation in the study.

Test setup

Procedure

48 h after a familiarisation session with the test (Sheppard &
Young, 2006), subjects participated in two test sessions to assess
the reliability of the data, with 48 h between sessions (Lockie,
Schultz, Callaghan, Jeffriess, & Berry, 2013; Sheppard & Young,
2006). Soccer players attended three experimental sessions (one
familiarisation and two identical testing sessions). The players
first performed the linear sprint test and then, the curve sprint
test. The only instructions before curve sprint test were: 1. Start
the sprint from behind start line (1 m distance to the first timing
gate set), 2. Follow the arc line of the area as a guiding line, 3. If
you do not sprint on the guiding line, the test will not be
considered valid and 4. After receiving the go ahead, you can
start when you’re ready. During data collection, three sets of
timing gates were used over 17 m. This enables split times to
be measured for 8.5 m and 17 m sprints. All the players recovered
the same time between each sprint. Each of the repetition times
was measured by a photoelectric cell system (Microgate Witty,
Italy) set at 90 cm height all timing gates in both sides.

Setup
Prior to data collection in the first testing session, each subject’s
age, height and body mass were recorded. The warm-up exercises
were: 5 min of jogging at a self-selected pace followed by a series
of dynamic warm-up drills and three practice sub-maximal trials
for linear and curve sprints. Subjects completed two different tests
within a session: the 17 m linear sprint and curve sprint. All tests

–
were performed under similar environmental conditions (13 16ºC,
and 35–39% of relative humidity), on artificial grass and executed
them in a random order that was maintained across the two

sessions.

The trial was considered “successful” when the subject ran
on the guideline (arc of the area). All the trials were recorded for
analysis. The subjects performed successfully three times each
test (the average of the three attempts was recorded), with
a total of nine tests with 3 min of recovery between each one
and a minute and 30 s between sets: 3 x linear sprint + 3 x right
curve sprint + 3 x left curve sprint.

Linear Sprint Test. Running speed was evaluated using

–
17 m sprint times (0 17 m) (standing start) with 8.5 m split
times. The front foot was placed 1 m before the first timing gate
in split standing start (Cronin, Green, Levin, Brughelli, & Frost,
2007).

Curve Sprint Test. The trajectory used to measure the sprint
in curve was the arc of the area (regulation soccer field), which
has the following characteristics (Figure 1 and Figure 2):

- Radius (from the penalty spot): 9.15 m.

- Distance from initial point to final point of the curve in

a straight line: 14.6 m.

- Amplitude of the angle from the point of penalty spot:

105.84º

- Total distance of the sprint curve: 17 m (obtained through

basic trigonometric analysis).

Running curve speed was evaluated by 17 m sprint times

– –
(0 17 m) (standing start) with 8.5 m (0 8.5 m) split time. The
front foot was placed 1 m before the first timing gate and
following the line of the arch of the area. Both sides were
measured (left and right). According to the mean time spent
for the three trials for each side, we considered the slowest as
the “weak” side, and the fastest as the “good” side.

Statistical analyses

The statistical analysis was performed using the SPSS 17.0 (SPSS,
Chicago, IL). Descriptive statistics are expressed as mean ± standard deviations (SD), in addition to 95% confidence limits (95%
CL). The normality of the data distribution was checked using the
Kolmogorov–Smirnov test.

For the relative reliability analysis, intra-class correlation
coefficients (ICC) were used. An ICC equal to or above 0.7 was
considered acceptable (Baumgartner & Chung, 2001). Intersession reliability was determined, using the best successfully
(previously defined) data from each day and each variable
obtained (8.5 m CSLS, CSRS and linear, and 17 m CSLS, CSRS,
and linear), via ICCs and two other separate measures
(Sheppard & Young, 2006).

Figure 1. Characteristics of the area to measure the sprint in curve.

Figure 2. Soccer player performing new curve sprint test.

Absolute reliability is the degree to which repeated measurements vary for individuals and the spreadsheet of Hopkins
(2000) (Hopkins, 2000) was used to determine the typical error
(TE) (s), expressed as a coefficient of variation (CV, %) (Hopkins,
Schabort, & Hawley, 2001). A CV of less than 5% was set as the
criterion for reliability.

Association between variables to determine the relationships
between curve sprint speed (in both “weak” and “good” sides)
and linear sprint speed, to help coaches and sport scientists
estimate the extent of variation in straight sprint performance
to a given variation in curvilinear sprint performance (i.e., shared
variance). Total variance was reported by the coefficient of determination (R \[2\] ) and the respective level of significance (p \< 0.05).
Additionally, a Pearson product moment correlation coefficient
was used to test the correlation between “weak” and “good”
curve sprint performances, which was classified according to the
criteria defined by Hopkins et al. (Hopkins, Marshall, Batterham, &
Hanin, 2009). The level of significance was set at p \< 0.05.

JOURNAL OF SPORTS SCIENCES 3

Results

Table 1 presents the descriptive data of both session 1 and
session 2, which also shows data about relative reliability statistics (mean, 95% confidence limit, p value and ICC). In terms of
relative reliability of different sprint test, the ICC of each test was
greater than 0.7, specifically 0.93 sprint curve right side (CSRS)
and 0.89 sprint curve left side (CSLS), considered “acceptable”.
There were no significant differences between the most of test
attempts. However, there were statistical differences between
session 1 and 2 in the CSRS (17 m) and CSLS (8.5 m). The effect
size (ES) showed a “small effect” in both conditions and “noneffect” for the rest of the tests (Cohen, 1988; Hopkins, 2004).

Table 1 shows the data related to the absolute reliability of the
different tests. Descriptive data of the two testing sessions and the
TE values expressed as %CV calculated from two consecutive
sessions are presented in Table 1. The mean CV was calculated
from both the testing sessions 1 and 2. The CV of each test was less
than 5%, specifically 0.87% in CSRS (17 m) and 1.15% in CSLS

4 A. FÍLTER ET AL.

Table 1. Descriptive data for testing sessions 1 and 2 to know relative and absolute reliability data with mean, p value for differences between the sessions, effect size
(ES), reliability statistics (intra-class correlation coefficient \[ICC\], typical error \[TE\], coefficient variations \[CV\]) in semi-professional soccer players.

Relative CV Absolute

Sprints Session 1 (s) Session 2 (s) Mean and 95% CL (s) p value ES ICC (CL95%) reliability TE % reliability

8.5m CSRS 1.43 ± 0.09 1.42 ± 0.09 1.43 (1.41–1.45) .245 .13 .83 (.65 – .92) Accep. .04 1.43 Accep.
17m CSRS 2.59 ± 0.12 2.57 ± 0.12 2.58 (2.54–2.59) .003\*.34 .93 (.85 – .97) Accep. .03 0.87 Accep.
8.5m CSLS 1.42 ± 0.1 1.39 ± 0.08 1.4 (1.32–1.42) .005\* .32 .75 (.52 – .88) Accep. .05 1.74 Accep.
17m CSLS 2.56 ± 0.13 2.54 ± 0.11 2.55 (2.5–1.57) .182 .15 .89 (.78 – .95) Accep. .06 1.15 Accep.
8.5m Lin 1.47 ± 0.13 1.48 ± 0.14 1.48 (1.4 – 1–53) .218 .14 .89 (.75 – .95) Accep. .05 1.97 Accep.
17m Lin 2.53 ± 0.13 2.54 ± 0.13 2.54 (2.54–2.57) .104 .18 .96 (.92 – .98) Accep. .03 0.5 Accep.

Sprints Session 1 (s) Session 2 (s) Mean and 95% CL (s) p value ES ICC (CL95%)

Relative
reliability TE

CV

%

- Significant differences (p ≤ 0.05) between sessions; CSRS: curve sprint right side; CSLS: curve sprint left side; Lin: Linear; Accept: acceptable; TE: typical error; CV:

coefficient variations; CL: confidence limits; ES: effect size; ICC: Intra-class correlation coefficient.

(17 m). The data presented in Table 1 confirm the reliability of the
test (reproducibility and temporary changes).

The coefficients of determination reveal that curve sprinting
(in both good and weak sides) and linear sprinting performances
are separate and specific physical capabilities in experienced
soccer players (34% and 37% of shared variance, respectively)
(Table 3). This indicates that players who ran faster in linear
sprints were not necessarily faster in curvilinear trajectories. In
contrast, a positive and “very large” (r = 0.88) correlation (Hopkins
et al., 2009) was found between the curve sprint performances
obtained in both “weak” and “good” sides; therefore, athletes
who were faster to sprint to “one side” were equally able to sprint
faster to “the other side”.

Discussion

The main findings of this study were (a) reliability criteria of
a universally standardised curve sprint test (that uses the 9.15
radius penalty arc as a “guide-line”) were confirmed in experienced soccer players, and (b) performance in this curve sprint
test showed limited relationship with performance in a same
length lineal sprint, which suggest that curve and straight
sprinting abilities are different physical qualities.

Relative and absolute reliability

Previous research has found good reliability for measures of linear
sprint and COD speed, reporting acceptable ICCs (>0.7) and CVs
(\<5%) in both linear sprint and COD tests (Little & Williams, 2005).
In the present study, ICCs for the sprint CSRS and CSLS (17 m) tests
were 0.93 and 0.89, respectively, indicating higher levels of relative
reliability. Moreover, a small TE, expressed as %CV of 0.87% and
1.15% (for CSRS and CSLS, respectively) also shows higher absolute reliability. Interestingly, those values are quite similar than
those reported in other studies regarding linear sprint assessments (CV ~0.9%) (Hopkins et al., 2001).

Although it is first curved test is used and its comparison
with other studies is difficult, intermediate reliability results
between COD and linear sprint could be expected, since the
curved path could imply a movement pattern less remote
from the linear sprint, compared to the COD. However, it
doesn’t happen. Most of the nonlinear sprint trajectories in
a soccer match are curved (Caldbeck, 2019) with small radius
(from 3.5 to 11 m) (Brice, Smith, & Dyson, 2004) and less than
20 m long (Barnes et al., 2014). So, the specificity of our test
(9.15 m radius, 17 m length) could be responsible, at least in

part, for this similarity of reliability values with those of the
linear sprint.

Relationship with linear sprint performance

Comparing the linear relationship between curvilinear and linear
sprints, shared variances between these capabilities were 34%
and 37% for “good” and “weak” side, respectively. This indicates
that straight sprint can explain only a very limited variability of
curve sprint (i.e., ~35%) and also confirms the hypothesis that
faster soccer players in straight sprints are not necessarily faster
in curvilinear trajectories. Previous research demonstrated the
specificity of linear sprinting when compared to COD speed,
describing moderate associations (r = 0.35) between
10 m sprint and Zigzag test (i.e., a 20 m COD test consisting of
3 turns at 100°) (Little & Williams, 2005), and also “low” and
“moderate” correlations between linear sprint and different
COD tests (Cinarli, Kafkas, & Kafkas, 2018). In the same way that
these studies have led to the development of specific COD
training, our results suggest that curve and lineal sprint should
be assessed and (probably) trained as separate physical qualities,
since they are different functional skills.

Lastly, our results showed a “very large” (r = 0.878) correlation between the curve sprint performance obtained by the
subjects in both “good” and “weak” sides (Table 2), revealing
that soccer players who run faster to one side (e.g., to the right
side) possibly run fast to the other side (e.g., to the left side).
Initially, it would make sense to expect differences between
both sides due to the specialisation of each player based on

Table 2. Pearson’s correlation and coefficient of determination (R \[2\] ) (p ≤ 0.05)
were used to define relationship between “good/weak” sprint curve.

Sprint curve “good” side (17m)

Sprint curve “weak” side (17m) r .878
R \[2\] .77

p \< .001†

- Significant (p ≤ 0.01) relationship between variables.

Table 3. Coefficient of determination (R \[2\] ) (p ≤ 0.05) was used to calculate the
proportion of the curve sprint variance explained by the linear sprint.

Sprint curve “good”

Sprint curve “weak”

side (17m) side (17m)

Sprint curve “weak” R \[2\] .77

side (17m)

Sprint curve “weak” R \[2\] .77

side (17m) p \< .001†

Linear sprint (17m) R \[2\] .34 .37
p \< .001† \< .001†

side (17m)

- Significant (p ≤ 0.01) variance explained.

their position on the pitch. However, in the analysed team there
was a similar proportion of left and right side midfielders,
wingers and full-backs (heterogeneous sample), and the present study did not analyse categorising by player’s position,
which was the main limitation of this study. Future studies are
necessary to know if within the same player’s position there is
relationship between “good” and “weak” side curve sprint
performance.

Other relevant data regarding linear sprint

Another relevant data was the average of each variable. It has
been reported lower speed in curve sprints than in linear sprints
regardless of radii (1, 2, 3, 4 and 6 m) in sprinters (Chang & Kram,
2007). Briefly, when the radius decreases, the sprint performance
tends to decrease. Likewise, Churchill et al. (2015) observed higher
velocities in linear sprints than in curve sprint in track and field
athletes. Curiously, for the first time, we recorded higher speeds
during curvilinear than linear trajectories in 27 of 40 subjects,
specifically when considering the “good side” measurement result
within a distance of 17 m and a radius of 9.15 m (i.e., testing data:
sprint curve “good” side = 2.5 s, linear sprint = 2.55 s, and sprint
curve “weak” side = 2.63 s). This on the one hand suggests again
the need to investigate the influence of player’s position on
“good” and “weak” sides performance, and on the other suggest
that these differences regarding Churchill et al. study (Churchill
et al., 2015) (with a sample of track and field athletes) could be
partially due to the specificity of the test, since this curvilinear
motion regularly occur more than linear in soccer (Bloomfield
et al., 2007; Caldbeck, 2019). Anyway, our limited sample (40
experienced players) prevents us from understanding our results
as reference values and requires further studies to confirm these
results.

In summary, the coefficients of determination indicated that
curve and linear sprint performances have a limited explained
variance of ~35%, in both “good” and “weak” sides, in experienced
soccer players. This suggests that curve and straight sprinting
abilities are different physical qualities and, consequently, should
be assessed and trained in isolated conditions. As the number of

maximum curve sprints throughout soccer games seems to be
influenced by matching demands (Bloomfield et al., 2007;
Caldbeck, 2019), additional studies should be conducted to examine the differences in performance between distinct playing positions. Finally, due to the importance of curvilinear sprint
performance in professional soccer, further studies are required
to test the effectiveness of different training strategies in improving this ability in elite soccer players.

Practical applications

The proposed “curve sprint test” is a specific soccer speed
measurement, performed in the arc of the area, within
a radius of 9.15 m (official FIFA radius) and a distance of
17 m. The data reported herein confirm that, when executed
under these standardised parameters, this universally standardised test can provide a very precise and reliable measure of
curvilinear sprint performance. As curve sprinting is an essential
and decisive action during soccer games and possess a limited
relationship with linear sprinting speed (i.e., ~35% of shared

JOURNAL OF SPORTS SCIENCES 5

variance), and taking into account that the radius and length of
the sprints vary in the real competition (which makes difficult
a complete transfer of curve test performance to the competition performance), strength and conditioning coaches and
sport scientists are encouraged to assess and train this capability in a separate way. These findings open new lines of research
regarding the biomechanical (e.g., kinematic and kinetic factors), physiological and neuromuscular characteristics of maximal curvilinear sprinting actions in soccer players from
different levels, genders and age-categories.

Disclosure statement

No potential conflict of interest was reported by the authors.

ORCID

Alberto Fílter <http://orcid.org/0000-0002-0040-0624>
Jesús Olivares <http://orcid.org/0000-0003-4748-4578>
Alfredo Santalla <http://orcid.org/0000-0001-9418-0564>
Fabio Y. Nakamura <http://orcid.org/0000-0002-5336-3652>
Irineu Loturco <http://orcid.org/0000-0003-1309-2568>
Bernardo Requena <http://orcid.org/0000-0002-2398-5370>

References

Barnes, C., Archer, D., Hogg, B., Bush, M., & Bradley, P. (2014). The

evolution of physical and technical performance parameters in the
English premier league. International Journal of Sports Medicine, 35(13),

1095–1100.
Baumgartner, T., & Chung, H. (2001). Confidence limits for intraclass relia
bility coefficients. Measurement in Physical Education and Exercise
Science, 5(3), 179–188.
Bloomfield, J., Polman, R., & O’Donoghue, P. (2007). Physical demands of

different positions in FA premier league soccer. Journal of Sports
Sciences, 6(1), 63–70.
Bradley, P., Di Mascio, M., Peart, D., Olsen, P., & Sheldon, B. (2010). High
intensity activity profiles of elite soccer players at different performance levels. Journal of Strength & Conditioning Research, 24(9),

2343–2351.

Brice, P., Smith, N., & Dyson, R. (2004). Frequency of curvilinear motion

during competitive soccer play. Communication to the fourth congress
of science and football. Journal of Sports Science; Part II: Game Activity
and Analysis, 22, 502.
Brice, P., Smith, N., & Dyson, R. (2008). Curve running in soccer:

Kinematics differences between the inside and outside limbs.
Proceedings of the XXVI International Conference of the Society of
Biomechanics in Sports.International Society of Biomechanics in
Sports, Seoul, Korea.
Brughelli, M., Cronin, J., Levin, G., & Chaouachi, A. (2008). Understanding

change of direction ability in soccer: A review of resistance training
studies. Sports Medicine, 38(12), 1045–1063.
Burgess, D., Naughton, G., & Norton, K. (2006). Profile of movement

demands of national football players in Australia. Journal of Science
and Medicine in Sport, 9(4), 334–341.
Caldbeck, P. (2019). Contextual Sprinting in Football. Impress. (DSportExSci

thesis). John Moores University, Liverpool, UK.
Cardoso de Araújo, M., Baumgart, C., Freiwald, J., & Hoppe, M. (2017).

Nonlinear sprint performance differentiates professional from young
soccer players. Journal of Sports Medicine and Physical Fitness, 58(9),

1204–1210.
Chang, Y., & Kram, R. (2007). Limitations to maximum running speed on flat

curve. Journal of Experimental Biology, 210(Pt 6), 971–982.
Churchill, S., Salo, A., & Trewartha, G. (2015). The effect of the bend on

technique and performance during maximal effort sprinting. Sports
Biomechanics, 14(1), 106–121.

6 A. FÍLTER ET AL.

Churchill, S., Trewartha, G., Bezodis, I., & Salo, A. (2016). Force produc
tion during maximal effort bend sprinting: Theory vs reality.
Scandinavian Journal of Medicine & Science in Sports, 26(10),

1171–1179.

Churchill, S., Trewartha, G., & Salo, A. (2018). Bend sprinting performance:

New insights into the effect of running lane. Sports Biomechanics, 18(4),

437–447.

Cinarli, F., Kafkas, A., & Kafkas, M. (2018). Relationship between linear

running and change of direction performances of male soccer players.
Turkish Journal of Sport and Exercise, 20(2), 93–99.
Cohen, J. (1988). Statistial power analysis for the behavioral science (Second

Edition ed.). Hillsdale: Erlbaum.
Cronin, J., Green, J., Levin, G., Brughelli, M., & Frost, D. (2007). Effect of

starting stance on inicitial sprint performance. Journal of Strength &
Conditioning Research, 21(3), 990–992.
Faude, O., Koch, T., & Meyer, T. (2012). Straight sprinting is the most

frequent action in goal situations in professional football. Journal of
Sports Sciences, 30(7), 625–631.
Haugen, T., Tonnessen, E., Hisdal, J., & Seiler, S. (2013). The role and devel
opment of sprinting speed in soccer. International Journal of Sport
Physiology and Performance, 9(3), 432–441.
Hopkins, W. (2000). Reliability from consecutive pairs of trials (excel

[spreadsheet). Available from: http://www.sportsci.org/resource/](http://www.sportsci.org/resource/stats/xrely.xls)
[stats/xrely.xls](http://www.sportsci.org/resource/stats/xrely.xls)
Hopkins, W. (2004). How to interpret changes in a athletics performance

test? Sports Scicience a Peer, 8, 1–7.

Hopkins, W., Marshall, S., Batterham, A., & Hanin, J. (2009). Progressive

statistics for studies in sports medicine and exercise science. Medicine
and Science in Sports & Exercise, 41(1), 3–13.
Hopkins, W., Schabort, E., & Hawley, J. (2001). Reliability of power in physical

performance test. Sports Medicine, 31(3), 211–234.
Little, T., & Williams, A. (2005). Specificity of acceleration, maximum speed,

and agility in professional soccer players. Journal of Strength &
Conditioning Research, 19(1), 76–78.
Lockie, R., Schultz, A., Callaghan, S., Jeffriess, M., & Berry, S. (2013). Reliability

and validity of a new test of change of direction speed for field-based
sports: The change of direction and acceleration test (CODAT). Journal of
Sports Science and Medicine, 12(1), 88–96.
Mohr, M., Krustrup, P., & Bangsbo, J. (2003). Match performance of

high-standard soccer players with special reference to development
of fatigue. Journal of Sports Sciences, 21(7), 519–528.
Rampini, E., Coutts, A., Castagna, C., Sassi, R., & Impellizzeri, F. (2007).

Variation in top level soccer match performance. International Journal
of Sports Medicine, 28(12), 1018–1024.
Sheppard, J., & Young, W. (2006). Agility literature review: Classifications,

training and testing. Journal of Sports Sciences, 24(9), 919–932.
Smith, N., Dyson, R., Hale, T., & Janaway, L. (2006). Contributions of the

inside and outside leg to maintenance of curvilinear motion on a natural
surface. Gait & Posture, 24(4), 453–458.
Smith, N., Dyson, R., & Hate, T. (1997). Lower extremity muscular adaptations to

curvilinear motion in soccer. Journal of Human Movement Studies, 33(4),

139–153.
